#!/bin/bash

mversion=2.0
TTSENGINE=cepstral

echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"

# Copy files

perm_dir=775
perm_files=644
perm_exec=775

src=.
dst=

echo "Installing Web script..."
wwwdirselect=/var/www
echo $n "Enter apache web root directory[$wwwdirselect]: $c"
read wwwdiruser
if [ -n "$wwwdiruser" ]; then
	wwwdirselect=$wwwdiruser
fi
echo "Selected www dir : $wwwdirselect"

mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE
install -m $perm_files $src/www/* $dst/$wwwdirselect/tts/$TTSENGINE

echo "--- $TTSENGINE HTTP/TTS $mversion installation has finished ---"

